@@ -21,6 +21,8 @@ along with ProtonVPN.  If not, see <https://www.gnu.org/licenses/>.
 """
 import asyncio
 import copy
+from threading import Event
+from typing import Optional
 
 from proton.vpn import logging
 from proton.vpn.core.connection import VPNConnector
@@ -35,6 +37,8 @@ from proton.vpn.core.usage import UsageReporting
 
 from proton.session.api import Fido2Assertion
 
+from proton.vpn.session.u2f_interaction import UserInteraction
+
 logger = logging.getLogger(__name__)
 
 
@@ -137,15 +141,43 @@ class ProtonVPNAPI:  # pylint: disable=too-many-public-methods
     def is_fido2_lib_available(self) -> bool:
         """
         Returns whether we support U2F/FIDO2 security keys for 2FA on this platform.
+
+        This is deprecated, use is_fido2_available instead.
         """
+        logger.warning("is_fido2_lib_available is deprecated, use is_fido2_available instead")
         return bool(self._session_holder.session.fido2_lib_available)
 
-    async def generate_2fa_fido2_assertion(self) -> Fido2Assertion:
+    @property
+    def supports_fido2(self) -> bool:
+        """
+        Returns if
+        - We support U2F/FIDO2 security keys for 2FA on this platform.
+        - The user has fido2 keys registered.
+
+        This only returns True if both conditions are met and if the user
+        is currently authenticating a session that requires 2FA.
+        """
+        lib_available = self.is_fido2_lib_available
+        supports_fido2 = self._session_holder.session.supports_fido2
+        return bool(lib_available and supports_fido2)
+
+    async def generate_2fa_fido2_assertion(
+            self,
+            user_interaction: Optional[UserInteraction] = None,
+            cancel_assertion: Optional[Event] = None
+    ) -> Fido2Assertion:
         """
         Generates a 2FA assertion using a U2F/FIDO2 security key.
-        :return: The generated FIDO2 assertion.
+
+        :param user_interaction: object handling any required user interaction
+            while generating the assertion.
+        :param cancel_assertion: optional event that can be set to cancel the
+        fido 2 assertion process.
+        :returns: the generated FIDO 2 assertion.
         """
-        return await self._session_holder.session.generate_2fa_fido2_assertion()
+        return await self._session_holder.session.generate_2fa_fido2_assertion(
+            user_interaction, cancel_assertion
+        )
 
     async def submit_2fa_fido2(self, fido2_assertion: Fido2Assertion) -> LoginResult:
         """
